==> location_plugin-0.0.1.tar.gz: android/src/main/java/com/ehsure/locationplugin/LocationPlugin.java <==
package com.ehsure.locationplugin;

import android.Manifest;
import android.app.Activity;
import android.os.Build;

import androidx.annotation.NonNull;

import com.tencent.map.geolocation.TencentLocation;
import com.tencent.map.geolocation.TencentLocationListener;
import com.tencent.map.geolocation.TencentLocationManager;
import com.tencent.map.geolocation.TencentLocationRequest;

import java.util.HashMap;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import pub.devrel.easypermissions.AfterPermissionGranted;
import pub.devrel.easypermissions.EasyPermissions;

/**
 * LocationPlugin
 */
public class LocationPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Activity activity;
    private TencentLocationManager locationManager;
    private Result result;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "location_plugin");
        channel.setMethodCallHandler(this);
    }

    @AfterPermissionGranted(1)
    private void requirePermission() {
        String[] permissions = {
                Manifest.permission.ACCESS_COARSE_LOCATION,
                Manifest.permission.ACCESS_FINE_LOCATION,
                Manifest.permission.READ_PHONE_STATE,
        };
        String[] permissionsForQ = new String[0];
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q) {
            permissionsForQ = new String[]{
                    Manifest.permission.ACCESS_COARSE_LOCATION,
                    Manifest.permission.ACCESS_FINE_LOCATION,
                    Manifest.permission.ACCESS_BACKGROUND_LOCATION, //target为Q时，动态请求后台定位权限
                    Manifest.permission.READ_PHONE_STATE
            };
        }
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q ?
                !EasyPermissions.hasPermissions(activity, permissionsForQ) : !EasyPermissions.hasPermissions(activity, permissions)) {
            EasyPermissions.requestPermissions(activity, "需要权限",
                    1, Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q ? permissionsForQ : permissions);
        }
    }

    private TencentLocationListener tencentLocationListener = new TencentLocationListener() {
        @Override
        public void onLocationChanged(TencentLocation tencentLocation, int i, String s) {
            if (i == TencentLocation.ERROR_OK) {
                double latitude = tencentLocation.getLatitude();
                double longitude = tencentLocation.getLongitude();
                String name = tencentLocation.getName();
                String address = tencentLocation.getAddress();
                HashMap<String,Object> hashMap = new HashMap<>();
                hashMap.put("latitude",latitude);
                hashMap.put("longitude",longitude);
                hashMap.put("name",name);
                hashMap.put("address",address);
                result.success(hashMap);
                locationManager.removeUpdates(tencentLocationListener);
            }
        }

        @Override
        public void onStatusUpdate(String s, int i, String s1) {

        }
    };

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getMyLocation")) {
            requestLocation();
            this.result = result;
        } else {
            result.notImplemented();
        }
    }

    private void requestLocation() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            requirePermission();
        }
        locationManager = TencentLocationManager.getInstance(activity);
        TencentLocationRequest locationRequest = TencentLocationRequest.create();
//        locationRequest.setInterval(3000);
        locationRequest.setRequestLevel(TencentLocationRequest.REQUEST_LEVEL_NAME);
        locationManager.requestLocationUpdates(locationRequest, tencentLocationListener);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {
        if (locationManager != null) locationManager.removeUpdates(tencentLocationListener);
    }

}

==> location_plugin-0.0.2.tar.gz: android/src/main/java/com/ehsure/locationplugin/LocationPlugin.java <==
package com.ehsure.locationplugin;

import android.Manifest;
import android.app.Activity;
import android.os.Build;

import androidx.annotation.NonNull;

import com.tencent.map.geolocation.TencentLocation;
import com.tencent.map.geolocation.TencentLocationListener;
import com.tencent.map.geolocation.TencentLocationManager;
import com.tencent.map.geolocation.TencentLocationRequest;

import java.util.HashMap;

import io.flutter.embedding.engine.plugins.FlutterPlugin;
import io.flutter.embedding.engine.plugins.activity.ActivityAware;
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import pub.devrel.easypermissions.AfterPermissionGranted;
import pub.devrel.easypermissions.EasyPermissions;

/**
 * LocationPlugin
 */
public class LocationPlugin implements FlutterPlugin, MethodCallHandler, ActivityAware {
    /// The MethodChannel that will the communication between Flutter and native Android
    ///
    /// This local reference serves to register the plugin with the Flutter Engine and unregister it
    /// when the Flutter Engine is detached from the Activity
    private MethodChannel channel;
    private Activity activity;
    private TencentLocationManager locationManager;
    private Result result;

    @Override
    public void onAttachedToEngine(@NonNull FlutterPluginBinding flutterPluginBinding) {
        channel = new MethodChannel(flutterPluginBinding.getFlutterEngine().getDartExecutor(), "location_plugin");
        channel.setMethodCallHandler(this);
    }

    @AfterPermissionGranted(1)
    private void requirePermission() {
        String[] permissions = {
                Manifest.permission.ACCESS_COARSE_LOCATION,
                Manifest.permission.ACCESS_FINE_LOCATION,
                Manifest.permission.READ_PHONE_STATE,
        };
        String[] permissionsForQ = new String[0];
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q) {
            permissionsForQ = new String[]{
                    Manifest.permission.ACCESS_COARSE_LOCATION,
                    Manifest.permission.ACCESS_FINE_LOCATION,
                    Manifest.permission.ACCESS_BACKGROUND_LOCATION, //target为Q时，动态请求后台定位权限
                    Manifest.permission.READ_PHONE_STATE
            };
        }
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q ?
                !EasyPermissions.hasPermissions(activity, permissionsForQ) : !EasyPermissions.hasPermissions(activity, permissions)) {
            EasyPermissions.requestPermissions(activity, "需要权限",
                    1, Build.VERSION.SDK_INT >= Build.VERSION_CODES.Q ? permissionsForQ : permissions);
        }
    }

    private final TencentLocationListener tencentLocationListener = new TencentLocationListener() {
        @Override
        public void onLocationChanged(TencentLocation tencentLocation, int i, String s) {
            if (i == TencentLocation.ERROR_OK) {
                HashMap<String,Object> hashMap = new HashMap<>();
                hashMap.put("latitude",tencentLocation.getLatitude());//返回当前位置的纬度.
                hashMap.put("longitude",tencentLocation.getLongitude());//返回当前位置的经度.
                hashMap.put("name",tencentLocation.getName());//返回当前位置的名称.
                hashMap.put("address",tencentLocation.getAddress());//返回当前位置的地址.
                hashMap.put("city",tencentLocation.getCity());//返回当前位置的城市.
                hashMap.put("cityCode",tencentLocation.getCityCode());//返回当前位置的城市编码.
                hashMap.put("province",tencentLocation.getProvince());//返回当前位置的省份.
                hashMap.put("district",tencentLocation.getDistrict());//返回当前位置的区县.
                hashMap.put("street",tencentLocation.getStreet());//返回当前位置的街道.
                hashMap.put("streetNo",tencentLocation.getStreetNo());//返回当前位置的街道编号.
                hashMap.put("town",tencentLocation.getTown());//返回当前位置的乡镇.
                hashMap.put("village",tencentLocation.getVillage());//返回当前位置的村.
                result.success(hashMap);
                locationManager.removeUpdates(tencentLocationListener);
            }
        }

        @Override
        public void onStatusUpdate(String s, int i, String s1) {

        }
    };

    @Override
    public void onMethodCall(@NonNull MethodCall call, @NonNull Result result) {
        if (call.method.equals("getMyLocation")) {
            requestLocation();
            this.result = result;
        } else {
            result.notImplemented();
        }
    }

    private void requestLocation() {
        if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.M) {
            requirePermission();
        }
        locationManager = TencentLocationManager.getInstance(activity);
        TencentLocationRequest locationRequest = TencentLocationRequest.create();
//        locationRequest.setInterval(3000);
        locationRequest.setRequestLevel(TencentLocationRequest.REQUEST_LEVEL_NAME);
        locationManager.requestLocationUpdates(locationRequest, tencentLocationListener);
    }

    @Override
    public void onDetachedFromEngine(@NonNull FlutterPluginBinding binding) {
        channel.setMethodCallHandler(null);
    }

    @Override
    public void onAttachedToActivity(ActivityPluginBinding binding) {
        activity = binding.getActivity();
    }

    @Override
    public void onDetachedFromActivityForConfigChanges() {

    }

    @Override
    public void onReattachedToActivityForConfigChanges(ActivityPluginBinding binding) {

    }

    @Override
    public void onDetachedFromActivity() {
        if (locationManager != null) locationManager.removeUpdates(tencentLocationListener);
    }

}
